Setting PolygonSelector vertices
--------------------------------
The vertices of `~matplotlib.widgets.PolygonSelector` can now be set
programmatically by using the `~matplotlib.widgets.PolygonSelector.verts`
property. Setting the vertices this way will reset the selector, and create
a new complete selector with the supplied vertices.
